@@ -1,5 +1,3 @@
-from typing import List
-
 from ...library import Library
 from ...model import Block, Entry
 from ..middleware import BlockMiddleware
@@ -11,8 +9,8 @@ class ReplaceFieldKeyInEntry(BlockMiddleware):
     def __init__(
         self,
         entry_type: str,
-        old_field_keys: List[str],
-        new_field_keys: List[str],
+        old_field_keys: list[str],
+        new_field_keys: list[str],
         allow_inplace_modification: bool = True,
     ):
         super().__init__(allow_inplace_modification=allow_inplace_modification, allow_parallel_execution=True)
@@ -24,7 +22,7 @@ class ReplaceFieldKeyInEntry(BlockMiddleware):
     # docstr-coverage: inherited
     def transform_entry(self, entry: Entry, library: Library) -> Block:
         if self.entry_type == entry.entry_type:
-            for old, new in zip(self.old_field_keys, self.new_field_keys):
+            for old, new in zip(self.old_field_keys, self.new_field_keys, strict=True):
                 if (old != new) and (old in entry):
                     entry[new] = entry[old]
                     del entry[old]
